/*************************************************************
 CRC7 - CRC7 checksum creator. Designed for use with Pololu
 motor controller (http://www.pololu.com/catalog/product/1110)

 This uses the default settings for the motor controller and the
 Compact Protocol to communicate to it.

 This library also depends on the NewSoftSerial library which
 can be found at: http://arduiniana.org.

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

 Author:  Edward Wilson (edwilson1989@gmail.com
 History:
 Version 1.0	August 6, 2010		Initial code

 ************************************************************/

#include "CRC7.h"

CRC7::CRC7() {

}

unsigned char CRC7::GetCRC(unsigned char val) {
	unsigned char j;
	for (j = 0; j < 8; j++) {
		if (val & 1)
			val ^= CRC7_POLY;
		val >>= 1;
	}
	return val;
}

unsigned char CRC7::CRC(unsigned char message[], unsigned char length) {
	unsigned char i, crc = 0;

	for (i = 0; i < length; i++)
		crc = CRCTable[crc ^ message[i]];
	return crc;
}

void CRC7::init(){
	GenerateCRCTable();
}

void CRC7::GenerateCRCTable() {
	int i, j;
		// generate a table value for all 256 possible byte values

		for (i = 0; i < 256; i++) {
			CRCTable[i] = GetCRC(i);
		}
}

