/**
 * @version 0.2
 * @mainpage
 *  CRC7 - CRC7 checksum creator. Designed for use with Pololu
 * motor controller (http://www.pololu.com/catalog/product/1110)
 *  This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * Author:  Edward Wilson (edwilson1989@gmail.com
 * Version 1.0	August 6, 2010		Initial code
*/


#ifndef CRC7_H_
#define CRC7_H_

/**
 * Polynomial used for the CRC calculation. This is the polynomial for CRC7.
 */
#define CRC7_POLY 0x91

/**
 * The CRC7 class is used to Calculate CRC7 values. It used a prehashed table so it is pretty heavy
 * on memory however it is lightening fast. With CRC computation it always a compromise between
 * memory and speed.
 *
 * When the Pololu Qik2s9v1 is in CRC mode it will expect a CRC for every command line it recieves.
 */
class CRC7: public CRC {
public:
	/**
	 * constructor this not longer generate the hash table. Invoke init() to do this.
	 *
	 * @see init()
	 */
	CRC7();

	/**
	 * Call this to has a message.
	 *
	 */
	unsigned char CRC(unsigned char message[], unsigned char length);

	/**
	 * Initialises the CRC engine.
	 * @since 0.2
	 */
	void void init();

private:

	/**
	 * used in the construction of the hash table.
	 */
	unsigned char GetCRC(unsigned char val);

	/**
	 * Generates the hash table.
	 */
	void GenerateCRCTable();

	/**
	 * memory allocated for hash table.
	 */
	unsigned char CRCTable[256];
};

#endif /* CRC7_H_ */
